Task: HotpotQA
===============
Description: HotpotQA is a dataset for multi-hop question answering.The overall setting is that given some context paragraphs(e.g., a few paragraphs, or the entire Web) and a question,a QA system answers the question by extracting a span of textfrom the context. It is necessary to perform multi-hop reasoningto correctly answer the question.

Link: https://arxiv.org/pdf/1809.09600.pdf

Tags: #HotpotQA, #All, #QA

